@@ -1,9 +1,9 @@
 package Music::MelodicDevice::Ornamentation;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Chromatic and diatonic musical ornamentation
+# ABSTRACT: Chromatic and diatonic melodic ornamentation
 
-our $VERSION = '0.0205';
+our $VERSION = '0.0206';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -77,8 +77,10 @@ sub grace_note {
     my $y = $MIDI::Simple::Length{yn} * TICKS; # Thirty-second note
     my $z = sprintf '%0.f', $x - $y;
     print "Durations: $x, $y, $z\n" if $self->verbose;
+    $y = 'd' . $y;
+    $z = 'd' . $z;
 
-    return [ ['d' . $y, $grace_note], ['d' . $z, $pitch] ];
+    return [ [$y, $grace_note], [$z, $pitch] ];
 }
 
 
@@ -118,7 +120,7 @@ sub turn {
 sub trill {
     my ($self, $duration, $pitch, $number, $offset) = @_;
 
-    $number ||= 4;
+    $number ||= 2;
     $offset //= 1;
 
     my $alt;
@@ -188,26 +190,25 @@ __END__
 
 =head1 NAME
 
-Music::MelodicDevice::Ornamentation - Chromatic and diatonic musical ornamentation
+Music::MelodicDevice::Ornamentation - Chromatic and diatonic melodic ornamentation
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 SYNOPSIS
 
   use Music::MelodicDevice::Ornamentation;
 
-  # Chromatic
-  my $md = Music::MelodicDevice::Ornamentation->new;
-  my $spec = $md->grace_note('qn', 'D5', 1);
-  $spec = $md->turn('qn', 'D5', 1);
-  $spec = $md->trill('qn', 'D5', 2, 1);
-  $spec = $md->mordent('qn', 'D5', 1);
+  my $md = Music::MelodicDevice::Ornamentation->new; # chromatic
 
-  # Diatonic
-  $md = Music::MelodicDevice::Ornamentation->new(scale_name => 'major');
-  $spec = $md->grace_note('qn', 'D5', 1);
+  $md = Music::MelodicDevice::Ornamentation->new( # diatonic
+    scale_note => 'C',
+    scale_name => 'major',
+    verbose => 1,
+  );
+
+  my $spec = $md->grace_note('qn', 'D5', -1);
   $spec = $md->turn('qn', 'D5', 1);
   $spec = $md->trill('qn', 'D5', 2, 1);
   $spec = $md->mordent('qn', 'D5', 1);
@@ -215,7 +216,7 @@ version 0.0205
 =head1 DESCRIPTION
 
 C<Music::MelodicDevice::Ornamentation> provides chromatic and diatonic
-musical ornamentation methods.
+musical melodic ornamentation methods.
 
 The duration part of the returned note specifications is actually in
 L<MIDI::Simple> C<d###> style, even though the SYNOPSIS shows them as
@@ -284,7 +285,7 @@ A trill is a B<number> of pairs of notes spread over a given
 B<duration>.  The first of the pair being the given B<pitch> and the
 second one given by the B<offset>.
 
-Default number: C<4>
+Default number: C<2>
 
 Default offset: C<1>
 
@@ -299,11 +300,11 @@ An B<offset> of C<1> (the default) returns an upper mordent one pitch
 away.  An B<offset> of C<-1> returns a lower mordent.
 
 So if the B<pitch> is C<D5>, a diatonic upper mordent would be
-C<D5-E5-D5>.  A chromatic lower mordent would be C<D5-C#5-D5>.
+C<D5 E5 D5>.  A chromatic lower mordent would be C<D5 C#5 D5>.
 
 =head1 SEE ALSO
 
-The F<t/01-methods.t> program in this distribution
+The F<t/01-methods.t> and F<eg/*> programs in this distribution
 
 L<Data::Dumper::Compact>
 
